darkhistory.physics.rho_baryon — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.rho_baryon

`darkhistory.physics.` `rho_baryon` = 234.26162599518608

  Baryon density in eV cm-3.

#### Previous topic

darkhistory.physics.rho_DM

#### Next topic

darkhistory.physics.nB

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.